<?php
/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

/**
 * This class represents an event type.
 *
 *
 * @author Niels Pardon <mail@niels-pardon.de>
 * @author Oliver Klee <typo3-coding@oliverklee.de>
 */
class Tx_Seminars_Model_EventType extends Tx_Oelib_Model implements Tx_Seminars_Interface_Titled
{
    /**
     * Returns our title.
     *
     * @return string our title, will not be empty
     */
    public function getTitle()
    {
        return $this->getAsString('title');
    }

    /**
     * Sets our title.
     *
     * @param string $title our title to set, must not be empty
     *
     * @return void
     */
    public function setTitle($title)
    {
        if ($title == '') {
            throw new InvalidArgumentException('The parameter $title must not be empty.', 1333296812);
        }

        $this->setAsString('title', $title);
    }

    /**
     * Gets the UID of the single view page for events of this type.
     *
     * @return int the single view page, will be 0 if none has been set
     */
    public function getSingleViewPageUid()
    {
        return $this->getAsInteger('single_view_page');
    }

    /**
     * Checks whether this event type has a single view page UID set.
     *
     * @return bool
     *         TRUE if this event type has a single view page set, FALSE
     *         otherwise
     */
    public function hasSingleViewPageUid()
    {
        return $this->hasInteger('single_view_page');
    }
}
